Class: Sumodev::Commands::Box
- Inherits:
-
Sumodev::Command
- Object
- Thor
- Sumodev::Command
- Sumodev::Commands::Box
- Defined in:
- lib/sumodev/commands/box.rb
Instance Method Summary collapse
Methods inherited from Sumodev::Command
Instance Method Details
#install ⇒ Object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/sumodev/commands/box.rb', line 60 def install # install vagrant plugins %x(vagrant plugin install vagrant-omnibus) %x(vagrant plugin install vagrant-vbguest) %x(vagrant plugin install vagrant-berkshelf) %x(berks vendor berks-cookbooks) # install .sumorc file File.open(File.("~/.sumorc"), 'w') do |f| f.write <<-SUMORC export SUMO_VAGRANT_PATH="" SUMORC end unless File.exists?(File.("~/.sumorc")) # setup resolver File.open("/tmp/vagrant-resolver", 'w') do |f| f.write <<-RESOLVER # Created by sumo command nameserver 10.11.12.13 port 53 RESOLVER end %x(sudo mv /tmp/vagrant-resolver /etc/resolver/vagrant) end |
#up ⇒ Object
49 50 51 52 53 54 55 56 57 |
# File 'lib/sumodev/commands/box.rb', line 49 def up say("There is already a box running, you should manually start the box. Or halt the running instance", :red) && exit(1) if box_running? convert_sumofile_into_env_variables configure_port_mapping run_vagrant_command("up", "--provision") rescue Sumodev::Sumofile::NoSuchFileError say("No Sumofile found! Please define one so the correct versions will be used!", :red) && exit(1) end |