Class: Sumodev::Commands::Box
- Inherits:
-
Sumodev::Command
- Object
- Thor
- Sumodev::Command
- Sumodev::Commands::Box
- Defined in:
- lib/sumodev/commands/box.rb
Instance Method Summary collapse
Methods inherited from Sumodev::Command
Instance Method Details
#install ⇒ Object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/sumodev/commands/box.rb', line 65 def install # install vagrant plugins %x(vagrant plugin install vagrant-ohai) %x(vagrant plugin install vagrant-omnibus) # install .sumorc file File.open(File.("~/.sumorc"), 'w') do |f| f.write " export SUMO_VAGRANT_PATH=\"\"\n" end unless File.exists?(File.("~/.sumorc")) # setup resolver File.open("/tmp/vagrant-resolver", 'w') do |f| f.write "# Created by sumo command\nnameserver 10.11.12.13\nport 53\n RESOLVER\n end\n\n %x(sudo mv /tmp/vagrant-resolver /etc/resolver/vagrant)\nend\n" |
#up ⇒ Object
54 55 56 57 58 59 60 61 62 |
# File 'lib/sumodev/commands/box.rb', line 54 def up say("There is already a box running, you should manually start the box. Or halt the running instance", :red) && exit(1) if box_running? convert_sumofile_into_env_variables configure_port_mapping run_vagrant_command("up", "--provision") rescue Sumodev::Sumofile::NoSuchFileError say("No Sumofile found! Please define one so the correct versions will be used!", :red) && exit(1) end |