Class: Sumodev::Commands::Box
Instance Method Summary
collapse
banner
Dynamic Method Handling
This class handles dynamic methods through the method_missing method
#method_missing(*args) ⇒ Object
69
70
71
|
# File 'lib/sumodev/commands/box.rb', line 69
def method_missing(*args)
run_vagrant_command(args.join(" "))
end
|
Instance Method Details
#up ⇒ Object
54
55
56
57
58
59
60
61
62
|
# File 'lib/sumodev/commands/box.rb', line 54
def up
say("There is already a box running, you should manually start the box. Or halt the running instance", :red) && exit(1) if box_running?
convert_sumofile_into_env_variables
configure_port_mapping
run_vagrant_command("up", "--provision")
rescue Sumodev::Sumofile::NoSuchFileError
say("No Sumofile found! Please define one so the correct versions will be used!", :red) && exit(1)
end
|
#your_command(*args) ⇒ Object
65
66
67
|
# File 'lib/sumodev/commands/box.rb', line 65
def your_command(*args)
say "Use sumo box <command> you bloody idiot, eg: sumo box ssh"
end
|